==> haskell-cryptohash-conduit-0.1.1-25-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cryptohash-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-8353f97b6e24bf6f7d83facec1b53829
key: crypt_2BHdyJ8T2kkKQJYFvKRGRJ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-2BHdyJ8T2kkKQJYFvKRGRJ
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
    conduit-extra-1.1.13.1-b0a6afe4d52c8bc50dff37cca54ee4a6
    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-27-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cryptohash-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-47b3295c0113c272521557c8fe3e3989
key: crypt_6WigTs3XkL7HMmT5msnKr2
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-6WigTs3XkL7HMmT5msnKr2
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
